<!--专项小组晾晒指标管理-->
<template>
    <div
        class="full-page bg"
        element-loading-text="数据加载中..."
        element-loading-spinner="el-icon-loading"
        element-loading-background="rgba(255,255,255, 0.5)"
        v-loading.fullscreen.lock="markLoading"
    >
        <div class="search-container">
            <el-form
                ref="form"
                :model="searchForm"
                label-width="auto"
                style="width: 100%"
            >
                <el-row :gutter="20">
                    <el-col :span="6">
                        <el-form-item label="指标名称">
                            <el-input
                                v-model="searchForm.name"
                                placeholder="请输入标题"
                                clearable
                            >
                            </el-input>
                        </el-form-item>
                    </el-col>

                    <el-col :span="2">
                        <el-button
                            icon="el-icon-search"
                            type="primary"
                            class="btn btn-plus"
                            @click="handleSearch(1)"
                        >
                            {{ this.$t('common.search') }}
                        </el-button>
                    </el-col>
                </el-row>
            </el-form>
        </div>
        <el-row :gutter="10" class="main-table-container flex">
            <el-col :span="24" class="table-container" ref="contentPanel">
                <div style="margin-bottom: 10px" ref="btnPanel">
                    <template>
                        <el-button
                            icon="el-icon-plus"
                            type="primary"
                            class="btn btn-plus"
                            @click="handleOpen('新增')"
                        >
                            新增
                        </el-button>
                        <el-button
                            slot="reference"
                            icon="el-icon-delete"
                            type="danger"
                            class="btn btn-delete"
                            :disabled="!deleteIds"
                            @click="handleDelete"
                        >
                            {{ this.$t('common.delete') }}
                        </el-button>
                    </template>
                </div>
                <div
                    :style="{width: '100%', height: `${tableMaxHeight}` + 'px'}"
                >
                    <el-table
                        stripe
                        size="mini"
                        v-loading="tableLoading"
                        ref="multipleSelection"
                        :data="tableData"
                        :max-height="tableMaxHeight"
                        :style="{width: '100%'}"
                        @selection-change="handleSelectionChange"
                    >
                        <el-table-column
                            type="selection"
                            width="55"
                            align="center"
                        ></el-table-column>
                        <el-table-column
                            type="index"
                            width="55"
                            label="序号"
                            align="center"
                        >
                        </el-table-column>
                        <el-table-column
                            prop="name"
                            show-overflow-tooltip
                            align="center"
                            label="指标名称"
                            sortable
                        >
                        </el-table-column>
                        <el-table-column
                            prop="key"
                            show-overflow-tooltip
                            align="center"
                            label="指标值"
                            sortable
                        >
                        </el-table-column>
                        <el-table-column
                            prop="unit"
                            show-overflow-tooltip
                            align="center"
                            label="指标单位"
                            sortable
                        >
                        </el-table-column>
                        <el-table-column
                            show-overflow-tooltip
                            width="120"
                            align="center"
                            fixed="right"
                            label="操作"
                        >
                            <template v-slot="{row}">
                                <template>
                                    <span>
                                        <el-link
                                            icon="el-icon-edit"
                                            type="primary"
                                            :underline="false"
                                            class="cloumn-btn"
                                            @click="handleOpen('编辑', row)"
                                        >
                                            编辑
                                        </el-link>
                                    </span>
                                </template>
                            </template>
                        </el-table-column>
                    </el-table>
                </div>
                <indexManageDialog
                    ref="indexManageDialog"
                    @refreshData="refreshData"
                ></indexManageDialog>
                <pagination
                    ref="paginationPanel"
                    style="margin-top: 10px"
                    :pageResult="params.pageBean"
                    @size-change="handleSizeChange"
                    @current-change="handleCurrentChange"
                />
            </el-col>
        </el-row>
    </div>
</template>

<script>
import pagination from '@/components/pagination'
import {TableMixin} from '@/mixins/tableMixin'
import indexManageDialog from './components/indexManageDialog.vue'
import moment from 'moment'
import req from '@/request.js'
const portal = window.context.portal
export default {
    name: 'specialGroupAiring',
    components: {
        pagination,
        indexManageDialog,
    },
    mixins: [TableMixin],
    data() {
        return {
            tableMaxHeight: 400,
            loading: false,
            tableLoading: false,
            tableData: [],
            params: {
                pageBean: {
                    page: 1,
                    pageSize: 20,
                    showTotal: true,
                },
                querys: [],
                sorter: [
                    {
                        direction: 'DESC',
                        property: 'fillDate',
                    },
                ],
            },
            pageResult: {
                page: 1,
                pageSize: 20,
                total: 0,
            },
            deleteIds: '', // 是否选中列表解锁删除按钮
            disabled: false, // 是否禁止输入输入
            active: true,

            addData: {},
            searchForm: {
                title: '',
                fillDate: '',
            }, // 顶部搜索对象
            markLoading: false,
        }
    },
    created() {
        // this.getData(this.params)
    },
    methods: {
        handleOpen(type, data) {
            this.$refs.indexManageDialog.open(type, data)
        },
        getData(data) {
            this.tableLoading = true
            req.post(
                `${portal}/majorProjects/bizSpecialGroupWork/v1/query`,
                data
            ).then((res) => {
                if (res) {
                    this.tableLoading = false
                    this.tableData = res.data.rows || []
                    this.params.pageBean = {
                        page: res.page,
                        pageSize: res.pageSize,
                        total: res.total,
                    }
                    this.tableLoading = false
                }
            })
        },
        refreshData() {
            this.handleSearch(1)
        },
        handleSearch(page) {
            this.tableLoading = true
            let data = JSON.parse(JSON.stringify(this.params))
            let obj = JSON.parse(JSON.stringify(this.searchForm))
            let querys = []
            for (let i in obj) {
                if (obj[i]) {
                    querys.push({
                        group: 'main',
                        operation: i == 'title' ? 'LIKE' : 'BETWEEN',
                        parentGroup: '',
                        property: i,
                        relation: 'AND',
                        value: obj[i],
                    })
                }
            }
            data.querys = [...data.querys, ...querys]
            data.pageBean.page = page
            this.getData(data)
        },
        handleCurrentChange(page) {
            this.params.pageBean = {...this.params.pageBean, page}
            this.handleSearch(page)
        },
        handleSizeChange(pageSize) {
            this.params.pageBean = {...this.params.pageBean, pageSize}
            this.handleSearch(1)
        },
        //获取删除数据id集合
        handleSelectionChange(val) {
            let arr = val.map((item) => item.id)
            this.deleteIds = arr.join(',')
        },
        //删除
        handleDelete() {
            this.$confirm('确认删除吗？', this.$t('common.tips'), {
                confirmButtonText: this.$t('common.confirm'),
                cancelButtonText: this.$t('common.cancel'),
                type: 'error',
            }).then(() => {
                this.markLoading = true
                req.remove(
                    `${portal}/majorProjects/bizSpecialGroupWork/v1/?ids=${this.deleteIds}`
                ).then((res) => {
                    console.log(res, 'res')
                    if (res.data && res.data.state) {
                        this.handleSearch(1)
                        this.$message.success('删除成功')
                        this.markLoading = false
                    } else {
                        this.$message.warning(res.data.message || '删除失败')
                        this.markLoading = false
                    }
                })
            })
        },
    },
}
</script>

<style lang="scss" scoped>

@import '~@/assets/css/element-variables.scss';
.cloumn-btn {
    border: 1px solid #2761ff;
    padding: 3px 10px;
    border-radius: 5px;

    &:nth-child(1) {
        margin-right: 5px;
    }

    &:nth-child(1):hover {
        background-color: #2761ff;
        color: #fff;
    }

    &:nth-child(2) {
        border: 1px solid #e6a23c;
    }
    &:nth-child(2):hover {
        background-color: #e6a23c;
        color: #fff;
    }

    /deep/ i,
    span {
        font-size: 16px;
    }
}

</style>